scikit-hubness: high-dimensional data mining — scikit-hubness 0.21.0a8 documentation

# scikit-hubness: high-dimensional data mining

scikit-hubness is a Python package for analysis and reduction of hubness in high-dimensional data. It provides a drop-in replacement for sklearn.neighbors with additional transparent support for approximate nearest neighbor search and hubness reduction.

## User Guide

The user guide explains how to install scikit-hubness, how to analyze your data sets for hubness, and how to use the package to lift this curse of dimensionality.

You will also find examples how to use skhubness.neighbors for approximate nearest neighbor search.

- scikit-hubness: successor to the Hub-Toolbox
- Installation
  - From PyPI
  - Dependencies
  - From Source
  - Supported platforms
- Tutorial
  - Installation
  - Tutorial 1
  - Tutorial 2

## API Documentation

The API documentation provides detailed information of the implemented methods. This information includes method’s descriptions, parameters, references, examples, etc. Find all the information about specific modules and functions of scikit-hubness in this section.

- API Documentation
  - Analysis: `skhubness.analysis`
  - Neighbors: `skhubness.neighbors`
  - Reduction: `skhubness.reduction`

- Search Page